@@ -26,16 +26,9 @@ G_BEGIN_DECLS
 typedef enum
 {
   META_BUTTON_TYPE_MENU,
-  META_BUTTON_TYPE_APPMENU,
   META_BUTTON_TYPE_MINIMIZE,
   META_BUTTON_TYPE_MAXIMIZE,
   META_BUTTON_TYPE_CLOSE,
-  META_BUTTON_TYPE_SHADE,
-  META_BUTTON_TYPE_UNSHADE,
-  META_BUTTON_TYPE_ABOVE,
-  META_BUTTON_TYPE_UNABOVE,
-  META_BUTTON_TYPE_STICK,
-  META_BUTTON_TYPE_UNSTICK,
   META_BUTTON_TYPE_SPACER,
   META_BUTTON_TYPE_LAST
 } MetaButtonType;
