@@ -131,7 +131,7 @@ struct _MetaWindow
   char *startup_id;
   char *gtk_theme_variant;
 
-  int net_wm_pid;
+  pid_t client_pid;
 
   Window xtransient_for;
   Window xgroup_leader;
@@ -526,12 +526,12 @@ void        meta_window_resize_with_gravity (MetaWindow  *window,
 /* Return whether the window would be showing if we were on its workspace */
 gboolean    meta_window_showing_on_its_workspace (MetaWindow *window);
 
+gboolean    meta_window_should_be_showing_on_workspace (MetaWindow    *window,
+                                                        MetaWorkspace *workspace);
+
 /* Return whether the window should be currently mapped */
 gboolean    meta_window_should_be_showing   (MetaWindow  *window);
 
-/* See warning in window.c about this function */
-gboolean    __window_is_terminal (MetaWindow *window);
-
 void        meta_window_update_struts      (MetaWindow  *window);
 
 /* this gets root coords */
@@ -724,6 +724,8 @@ void meta_window_add_pending_unmap (MetaWindow *window,
 gboolean meta_window_remove_pending_unmap (MetaWindow *window,
                                            gulong      serial);
 
+pid_t meta_window_get_client_pid (MetaWindow *self);
+
 G_END_DECLS
 
 #endif
