@@ -43,7 +43,6 @@
 #include "frame-private.h"
 #include "group.h"
 #include <X11/Xatom.h>
-#include <X11/extensions/XRes.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -396,74 +395,6 @@ reload_wm_window_role (MetaWindow    *window,
     window->role = g_strdup (value->v.str);
 }
 
-static pid_t
-get_local_pid (MetaWindow *window)
-{
-  pid_t pid;
-  XResClientIdSpec spec;
-  long num_ids;
-  XResClientIdValue *client_ids;
-  long i;
-
-  pid = -1;
-
-  spec.client = window->xwindow;
-  spec.mask = XRES_CLIENT_ID_PID_MASK;
-
-  XResQueryClientIds (window->display->xdisplay,
-                      1,
-                      &spec,
-                      &num_ids,
-                      &client_ids);
-
-  for (i = 0; i < num_ids; i++)
-    {
-      if (client_ids[i].spec.mask == XRES_CLIENT_ID_PID_MASK)
-        {
-          pid = XResGetClientPid (&client_ids[i]);
-          break;
-        }
-    }
-
-  XResClientIdsDestroy (num_ids, client_ids);
-
-  return pid;
-}
-
-static void
-reload_net_wm_pid (MetaWindow    *window,
-                   MetaPropValue *value,
-                   gboolean       initial)
-{
-  pid_t pid;
-
-  pid = get_local_pid (window);
-
-  if (pid != -1)
-    {
-      meta_verbose ("Ignoring _NET_WM_PID in favor of XResGetClientPid\n");
-
-      window->net_wm_pid = pid;
-      return;
-    }
-
-  if (value->type != META_PROP_VALUE_INVALID)
-    {
-      gulong cardinal = (int) value->v.cardinal;
-
-      if (cardinal <= 0)
-        {
-          g_warning ("Application set a bogus _NET_WM_PID %lu", cardinal);
-        }
-      else
-        {
-          window->net_wm_pid = cardinal;
-          meta_verbose ("Window has _NET_WM_PID %d\n",
-                        window->net_wm_pid);
-        }
-    }
-}
-
 static void
 reload_net_wm_user_time (MetaWindow    *window,
                          MetaPropValue *value,
@@ -618,21 +549,24 @@ set_title_text (MetaWindow  *window,
                       title, window->wm_client_machine);
       modified = TRUE;
     }
-  else if (window->net_wm_pid != -1)
+  else if (meta_window_get_client_pid (window) != -1)
     {
+      pid_t client_pid;
+      uid_t window_owner;
+      gboolean window_owner_known;
+      gboolean window_owner_is_us;
+
       /* We know the process which owns this window; perhaps we can
        * find out the name of its owner (if it's not us).
        */
 
-      char *found_name = NULL;
+      client_pid = meta_window_get_client_pid (window);
+      window_owner = 0;
 
-      uid_t window_owner = 0;
-      gboolean window_owner_known =
-              owner_of_process (window->net_wm_pid, &window_owner);
+      window_owner_known = owner_of_process (client_pid, &window_owner);
 
       /* Assume a window with unknown ownership is ours (call it usufruct!) */
-      gboolean window_owner_is_us =
-              !window_owner_known || window_owner==getuid ();
+      window_owner_is_us = !window_owner_known || window_owner==getuid ();
 
       if (window_owner_is_us)
         {
@@ -653,6 +587,7 @@ set_title_text (MetaWindow  *window,
             {
               /* Okay, let's look up the name. */
               struct passwd *pwd;
+              char *found_name = NULL;
 
               errno = 0;
               pwd = getpwuid (window_owner);
@@ -1574,6 +1509,8 @@ reload_wm_protocols (MetaWindow    *window,
   if (value->type == META_PROP_VALUE_INVALID)
     return;
 
+  meta_verbose ("Updating WM_PROTOCOLS for %s\n", window->desc);
+
   i = 0;
   while (i < value->v.atom_list.n_atoms)
     {
@@ -1588,10 +1525,6 @@ reload_wm_protocols (MetaWindow    *window,
         window->net_wm_ping = TRUE;
       ++i;
     }
-
-  meta_verbose ("New _NET_STARTUP_ID \"%s\" for %s\n",
-                window->startup_id ? window->startup_id : "unset",
-                window->desc);
 }
 
 static void
@@ -1845,12 +1778,6 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
       reload_wm_class,
       LOAD_INIT | INCLUDE_OR
     },
-    {
-      display->atom__NET_WM_PID,
-      META_PROP_VALUE_CARDINAL,
-      reload_net_wm_pid,
-      LOAD_INIT | INCLUDE_OR
-    },
     {
       XA_WM_NAME,
       META_PROP_VALUE_TEXT_PROPERTY,
