@@ -391,7 +391,7 @@ update_frame_flags (ThemeViewerWindow *window)
   GtkToggleButton *button;
 
   flags = META_FRAME_ALLOWS_DELETE | META_FRAME_ALLOWS_MENU |
-          META_FRAME_ALLOWS_APPMENU | META_FRAME_ALLOWS_MINIMIZE |
+          META_FRAME_ALLOWS_MINIMIZE |
           META_FRAME_ALLOWS_MAXIMIZE | META_FRAME_ALLOWS_VERTICAL_RESIZE |
           META_FRAME_ALLOWS_HORIZONTAL_RESIZE | META_FRAME_ALLOWS_SHADE |
           META_FRAME_ALLOWS_MOVE;
